==> ejc-probuilddiary-impl-3.0.0-20220916.100920-7-sources.jar: com/ejianc/business/probuilddiary/project/bean/ProjectLogExamineEntity.java <==
package com.ejianc.business.probuilddiary.project.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 项目日志-原材料检验、时间、试块及见证取样送检等情况（取样员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_project_log_examine")
public class ProjectLogExamineEntity extends BaseEntity {
	private static final long serialVersionUID = -7442060614193576814L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "mold_id")
	private Long moldId; // 工作类型id
	@TableField(value = "mold_name")
	private String moldName; // 工作类型名称
	@TableField(value = "mold_code")
	private String moldCode; // 工作类型编码
	@TableField(value = "make_name")
	private String makeName; // 试块制作情况名称
	@TableField(value = "inspect_name")
	private String inspectName; // 试块送检情况名称
	@TableField(value = "examine_name")
	private String examineName; // 现场检测名称名称
	@TableField(value = "examine_num")
	private BigDecimal examineNum; // 数量
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "file_type")
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getMoldId() {
		return moldId;
	}

	public void setMoldId(Long moldId) {
		this.moldId = moldId;
	}

	public String getMoldName() {
		return moldName;
	}

	public void setMoldName(String moldName) {
		this.moldName = moldName;
	}

	public String getMoldCode() {
		return moldCode;
	}

	public void setMoldCode(String moldCode) {
		this.moldCode = moldCode;
	}

	public String getMakeName() {
		return makeName;
	}

	public void setMakeName(String makeName) {
		this.makeName = makeName;
	}

	public String getInspectName() {
		return inspectName;
	}

	public void setInspectName(String inspectName) {
		this.inspectName = inspectName;
	}

	public String getExamineName() {
		return examineName;
	}

	public void setExamineName(String examineName) {
		this.examineName = examineName;
	}

	public BigDecimal getExamineNum() {
		return examineNum;
	}

	public void setExamineNum(BigDecimal examineNum) {
		this.examineNum = examineNum;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-impl-3.0.0-20220919.071841-10-sources.jar: com/ejianc/business/probuilddiary/project/bean/ProjectLogExamineEntity.java <==
package com.ejianc.business.probuilddiary.project.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 项目日志-原材料检验、时间、试块及见证取样送检等情况（取样员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_project_log_examine")
public class ProjectLogExamineEntity extends BaseEntity {
	private static final long serialVersionUID = -7442060614193576814L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "mold_id")
	private Long moldId; // 工作类型id
	@TableField(value = "mold_name")
	private String moldName; // 工作类型名称
	@TableField(value = "mold_code")
	private String moldCode; // 工作类型编码
	@TableField(value = "make_name")
	private String makeName; // 试块制作情况名称
	@TableField(value = "inspect_name")
	private String inspectName; // 试块送检情况名称
	@TableField(value = "examine_name")
	private String examineName; // 现场检测名称名称
	@TableField(value = "examine_num")
	private BigDecimal examineNum; // 数量
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "file_type")
	private String fileType; // 文件类型
	@TableField(value = "update_flag")
	private Boolean updateFlag; // 更新状态


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getMoldId() {
		return moldId;
	}

	public void setMoldId(Long moldId) {
		this.moldId = moldId;
	}

	public String getMoldName() {
		return moldName;
	}

	public void setMoldName(String moldName) {
		this.moldName = moldName;
	}

	public String getMoldCode() {
		return moldCode;
	}

	public void setMoldCode(String moldCode) {
		this.moldCode = moldCode;
	}

	public String getMakeName() {
		return makeName;
	}

	public void setMakeName(String makeName) {
		this.makeName = makeName;
	}

	public String getInspectName() {
		return inspectName;
	}

	public void setInspectName(String inspectName) {
		this.inspectName = inspectName;
	}

	public String getExamineName() {
		return examineName;
	}

	public void setExamineName(String examineName) {
		this.examineName = examineName;
	}

	public BigDecimal getExamineNum() {
		return examineNum;
	}

	public void setExamineNum(BigDecimal examineNum) {
		this.examineNum = examineNum;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public Boolean getUpdateFlag() {
		return updateFlag;
	}

	public void setUpdateFlag(Boolean updateFlag) {
		this.updateFlag = updateFlag;
	}
}
